FigmentLayer

Struct FigmentLayer 

pub struct FigmentLayer<T> { /* private fields */ }
Layer that deserializes T from a shared Figment on each Layer::build.

Implementations

Source

impl<T> FigmentLayer<T>

pub fn new(figment: Figment) -> Self

Layer that deserializes from an owned Figment on each build.

pub fn from_shared(figment: Arc<Figment>) -> Self

Layer that reuses an existing shared Arc<Figment> on each build.

pub fn figment(&self) -> &Figment

Borrow the merged Figment used for deserialization.